@@ -8,7 +8,13 @@ class Trigram(models.Model):
     word_i_minus_two = models.CharField(max_length=250)
     count = models.IntegerField()
 
+    def get_context(self):
+        return u'%s %s' % (word_i_minus_two,word_i_minus_one)
+
 class Bigram(models.Model):
     word = models.CharField(max_length=250)
     word_i_minus_one = models.CharField(max_length=250)
     count = models.IntegerField()
+
+    def get_context(self):
+        return u'%s %s' % (word_i_minus_two,word_i_minus_one)
